glados.core module — GLaDOS 0.0.1.dev14 documentation

# glados.core module

class `glados.core.` `Glados`(config_file=None, plugins_folder=None, bots_config_dir=None, plugins_config_dir=None)

  Bases: `object`

  Glados is the core of the GLaDOS package.

  `add_bot`(bot: glados.bot.GladosBot)

    Add a new bot to GLaDOS.

    Parameters

      bot (GladosBot) – the bot to be added to GLaDOS

  `add_plugin`(plugin: glados.plugin.GladosPlugin)

    Add a plugin to GLaDOS

    Parameters

      plugin (GladosPlugin) – the plugin to be added to GLaDOS

  `import_bots`()

    Import all discovered bots

  `import_plugins`(bot_name=None)

    Import all discovered plugins and add them to the plugin list.

  `read_config`(bot_name=None)
  `request`(request: glados.request.GladosRequest)

    Send a request to GLaDOS.

    Parameters

      request (GladosRequest) – the request to be sent to GLaDOS